<?php

namespace Teknisa\DF\Modules\Entrada\Factories;

use Doctrine\ORM\EntityManager;

use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
    
class Dfe47000LiberacaoParaFinanceiroFactory {

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function getDadosFilter($cdFilial) {
        $sql = "SELECT E.CDEMPRESA, E.NMEMPRESA, PF.DTPROCESSA 
                FROM EMPRESA E, FILIAL F, PARAMFILIAL PF
                WHERE F.CDFILIAL  = :P_CDFILIAL
                 AND  F.CDEMPRESA = E.CDEMPRESA
                 AND  F.CDFILIAL  = PF.CDFILIAL";

        $params = array("P_CDFILIAL" => $cdFilial);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll()[0];
    }
    
    public function cancelaVencimento($cdFilial, $nrLanctonf) {
        $procedure = new StoredProcedure($this->connection, 'CANCELA_DADOS_FINANCEIRO');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT,    $cdFilial,          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRLANCTONF', Param::PARAM_INPUT,  $nrLanctonf,        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDCANFIN', Param::PARAM_INPUT,    'N',                Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_RETORNO', Param::PARAM_OUTPUT,     '',                Param::PARAM_TYPE_STR, 1));
        $erro = $procedure->execute();
        if(isset($erro["P_RETORNO"])) {
            switch ($erro["P_RETORNO"]) {
                case '0': 
                    break;
                case '1':
                    throw new \Exception("Operação bloqueada. Documento possui boletos baixados.");
                    break;
                case '2':
                    throw new \Exception("Operação bloqueada. Documento possui vencimentos parcelados.");
                    break;
                case '3':
                    throw new \Exception("Operação bloqueada. Documento com vencimentos prorrogados.");
                    break;
                case '4':
                    throw new \Exception("Operação bloqueada. Documento com ajustes em boletos.");
                    break;
                case '5':
                    throw new \Exception("Operação bloqueada. Documento com boleto real.");
                    break;
                case '6':
                    throw new \Exception("Operação bloqueada. Documento relacionado à um boleto CNAB.");
                    break;
                case '7':
                    throw new \Exception("Operação bloqueada. Documento com boleto associado.");
                    break;
                default: 
                    throw new \Exception("Ocorreu um erro ao cancelar o vencimento.");
                    break;
            }   
        }
    }
    
    public function updateIdBloqueado($idbloqnfin, $cdoperactpg, $cdoperactpgcan, $dtliberacaofin, $cdfilial, $nrlanctonf) {
        $sql = "UPDATE NOTAFISCAL
                SET IDBLOQNFFIN = :P_IDBLOQNFIN,
                 CDOPERACTPG    = :P_CDOPERACTPG,
                 CDOPERACTPGCAN = :P_CDOPERACTPGCAN,
                 DTLIBERACAOFIN = :P_DTLIBERACAOFIN
                WHERE CDFILIAL  = :P_CDFILIAL
                AND NRLANCTONF  = :P_NRLANCTONF";
                
        $params = array("P_IDBLOQNFIN" => $idbloqnfin,
                        "P_CDOPERACTPG" => $cdoperactpg,
                        "P_CDOPERACTPGCAN" => $cdoperactpgcan,
                        "P_DTLIBERACAOFIN" => $dtliberacaofin,
                        "P_CDFILIAL" => $cdfilial,
                        "P_NRLANCTONF" => $nrlanctonf);
        
        $query = $this->connection->prepare($sql);
        return $query->execute($params);
    }
    
    public function getParamManifesta() {
        $sql = "SELECT NVL(IDCIENCIAEMISS, '0' ) IDCIENCIAEMISS, NVL(IDCONFIRMAEMISS, '0') IDCONFIRMAEMISS
                   FROM PARAMMANIFESTA";
                   
        $query = $this->connection->prepare($sql);
        $query->execute();
        return $query->fetchAll()[0];
    }
    
    public function getInscricaoEmpresa($cdEmpresa) {
        $sql = "SELECT NRINSJUREMPR FROM EMPRESA WHERE CDEMPRESA = :P_CDEMPRESA";
        
        $params = array("P_CDEMPRESA" => $cdEmpresa);
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll()[0];
    }
}
